@@ -1,6 +1,6 @@
 """A library for installing Python wheels."""
 
-__version__ = "0.2.3"
+__version__ = "0.5.1"
 __all__ = ["install"]
 
-from ._core import install  # noqa
+from installer._core import install  # noqa
